@@ -110,6 +110,8 @@ public:
     bool isXfce = false;
     bool isFluxbox = false;
     bool isKDE = false;
+    bool liqKernelUpdateFlag = false;
+    bool debianKernelUpdateFlag = false;
 
 
 
@@ -301,6 +303,10 @@ private slots:
 
     void on_lineEditSuperCommand_textChanged(const QString &arg1);
 
+    void on_checkBoxLiqKernelUpdates_clicked();
+
+    void on_checkBoxDebianKernelUpdates_clicked();
+
 private:
     Ui::defaultlook *ui;
 };
